package com.muyu.product.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.AsAttributeAttributeGroup;
import com.muyu.product.domain.AttributeGroup;
import com.muyu.product.domain.AttributeInfo;
import com.muyu.product.domain.req.AttributeGroupReq;
import com.muyu.product.domain.resp.AttributeGroupResp;
import com.muyu.product.service.AsAttributeAttributeGroupService;
import com.muyu.product.service.AttributeGroupService;
import com.muyu.product.service.AttributeInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName AttributeGroupController
 * @Description 描述
 * @Author ZHIHAO.DAI
 * @Date 2024/3/1 13:05
 */
@RestController
@RequestMapping("/attributeGroup")
public class AttributeGroupController {
    @Autowired
    private AttributeInfoService attributeInfoService;
    @Autowired
    private AsAttributeAttributeGroupService asAttributeAttributeGroupService;
    @Autowired
    private AttributeGroupService attributeGroupService;

    //获取属性组列表
    @GetMapping("/getAttributeGroupList")
    public Result<List<AttributeGroupResp>> getAttributeGroupList(@RequestParam("attributeName") String attributeName){
        QueryWrapper<AttributeGroup> queryWrapper = new QueryWrapper<>();
        if (attributeName!=null && !"".equals(attributeName)){
            queryWrapper.like("name",attributeName);
        }

        //这里得到的是属性组集合
        List<AttributeGroup> attributeGroupList = attributeGroupService.list(queryWrapper);
        //使用属性组集合中的每一个Id,来得到属性Id集合
        List<AttributeGroupResp> attributeGroupRespList = attributeGroupList.stream()
                .map(attributeGroup
                        -> AttributeGroupResp.groupFunBuild(attributeGroup,
                        id -> asAttributeAttributeGroupService.getAttributeGroupRespList(id)
                    )
                ).toList();

        //使用属性id集合,来获得属性集合

        return Result.success(attributeGroupRespList);

    }
    @PostMapping("/insertAttributeGroup")
    public Result insertAttributeGroup(@RequestBody AttributeGroupReq attributeGroupReq){
        AttributeGroup attributeGroup = AttributeGroup.BuildAttributeGroupByReq(attributeGroupReq);
        boolean save = attributeGroupService.save(attributeGroup);
        System.out.println("添加属性组之后返回的主键:"+attributeGroup.getId());
        attributeGroupReq.setAttributeGroupId(attributeGroup.getId());
        List<AsAttributeAttributeGroup> asAttributeAttributeGroupList = AsAttributeAttributeGroup.buildAttributeMiddle(attributeGroupReq);
        boolean b = asAttributeAttributeGroupService.saveBatch(asAttributeAttributeGroupList);
        if (b){
            return Result.success();
        }
        return Result.error();
    }

}
