package com.muyu.product.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.product.domain.AttributeInfo;
import com.muyu.product.service.AttributeInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

/**
 * @ClassName AttributeInfoController
 * @Description 描述
 * @Author ZHIHAO.DAI
 * @Date 2024/3/1 13:22
 */
@RestController
@RequestMapping("/attributeInfo")
public class AttributeInfoController {
    @Autowired
    private AttributeInfoService attributeInfoService;

    //查询所有属性
    @RequiresPermissions("product:attributeInfo:list")
    @GetMapping("/list")
    public Result<List<AttributeInfo>> getAttributeInfoList(@RequestParam("name") String name){
        LambdaQueryWrapper<AttributeInfo> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(name)){
            queryWrapper.like(AttributeInfo::getName,name);
        }
        List<AttributeInfo> list = attributeInfoService.list(queryWrapper);
        return Result.success(list);
    }
    //添加或者修改
    @RequiresPermissions("product:attributeInfo:add")
    @PostMapping("/insertAttribute")
    public Result insertAttribute(@RequestBody AttributeInfo attributeInfo){
        System.out.println(attributeInfo);
        if (attributeInfo.getId()==null){
            attributeInfo.setCreateBy(SecurityUtils.getUsername());
            attributeInfo.setCreateTime(new Date());
            boolean save = attributeInfoService.save(attributeInfo);
            if (save){
                return Result.success();
            }
            return Result.error();
        }else{
            attributeInfo.setUpdateBy(SecurityUtils.getUsername());
            attributeInfo.setUpdateTime(new Date());
            QueryWrapper<AttributeInfo> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("id",attributeInfo.getId());
            boolean update = attributeInfoService.update(attributeInfo,queryWrapper);
            if (update){
                return Result.success();
            }else {
                return Result.error("修改失败");
            }
        }

    }
    //删除
    @RequiresPermissions("product:attribute:delete")
    @GetMapping("/deleteAttributeById")
    public Result deleteById(@RequestParam("attributeInfoId") Integer attributeInfoId){
        boolean b = attributeInfoService.removeById(attributeInfoId);
        if (b){
            return Result.success();
        }
        return Result.error("位置错误,删除失败!");
    }



}
